using System;
using System.Collections.Generic;
using System.Text;
using System.IO;
using System.Runtime.InteropServices;
using System.Collections.Specialized;
using Microsoft.VisualBasic.FileIO;
using System.Windows.Forms;

namespace LControl
{
    public class LocalFileBrowser : FileBrowser
    {
        public LocalFileBrowser()
        {
            InitializeComponent();
        }

        protected override void CreateDirectory(string name)
        {
            Directory.CreateDirectory(name);
        }

        protected override void Paste(ItemInfo[] SrcFiles, string path, bool cut)
        {
            try
            {
                if (cut)
                {
                    foreach (ItemInfo item in SrcFiles)
                    {
                        if (item.Type == FileType.File)
                            FileSystem.MoveFile(((LFileInfo)item.Info).FullName, CurrentPath + "\\" + ((LFileInfo)item.Info).Name, UIOption.AllDialogs);
                        else
                            FileSystem.MoveDirectory(((LDirectoryInfo)item.Info).FullName, CurrentPath + "\\" + ((LDirectoryInfo)item.Info).Name, UIOption.AllDialogs);
                    }
                }
                else
                {
                    foreach (ItemInfo item in SrcFiles)
                    {
                        if (item.Type == FileType.File)
                            FileSystem.CopyFile(((LFileInfo)item.Info).FullName, CurrentPath + "\\" + ((LFileInfo)item.Info).Name, UIOption.AllDialogs);
                        else
                            FileSystem.CopyDirectory(((LDirectoryInfo)item.Info).FullName, CurrentPath + "\\" + ((LDirectoryInfo)item.Info).Name, UIOption.AllDialogs);
                    }
                }
                RefreshCurrentDirectory();
            }
            catch (Exception ex)
            {
                MessageBox.Show(this, ex.Message, LControl_Language.strMsgCap1);
            }
        }

        protected override void GetDrives(out LDriveInfo[] ldis)
        {
            try
            {
                DriveInfo[] dis = DriveInfo.GetDrives();
                ldis = new LDriveInfo[dis.Length];
                int i = 0;
                foreach (DriveInfo di in dis)
                {
                    ldis[i] = new LDriveInfo(di);
                    i++;
                }
            }
            catch (Exception ioe)
            {
                throw new GetDriveException(ioe.Message);
            }
        }

        protected override void GetDirectionsAndFiles(string path, string filter, out LDirectoryInfo[] Dirs, out LFileInfo[] Files)
        {
            try
            {
                DirectoryInfo[] dis = null;
                FileInfo[] fis = null;

                DirectoryInfo pdi = new DirectoryInfo(path);
                dis = pdi.GetDirectories();
                fis = pdi.GetFiles();

                Dirs = new LDirectoryInfo[dis.Length];
                Files = new LFileInfo[fis.Length];

                int i = 0;
                foreach (DirectoryInfo di in dis) Dirs[i++] = new LDirectoryInfo(di);
                i = 0;
                foreach (FileInfo fi in fis) Files[i++] = new LFileInfo(fi);
            }
            catch (Exception Error)
            {
                Dirs = null;
                Files = null;
                throw new GetDirsAndFilesException(Error.Message);
            }
        }

        protected override void GetSubDirectorys(string path, out LDirectoryInfo[] Dirs)
        {
            try
            {
                DirectoryInfo[] dis = null;

                DirectoryInfo pdi = new DirectoryInfo(path);
                dis = pdi.GetDirectories();

                Dirs = new LDirectoryInfo[dis.Length];

                int i = 0;
                foreach (DirectoryInfo di in dis) Dirs[i++] = new LDirectoryInfo(di);
            }
            catch (Exception Error)
            {
                Dirs = null;
                throw new GetSubDirsException(Error.Message);
            }
        }

        protected override void MoveTo(ItemInfo[] SrcFiles)
        {
            try
            {
                FolderBrowserDialog fbd = new FolderBrowserDialog();
                fbd.Description = LControl_Language.strLF_MoveTip;
                fbd.ShowDialog();
                if (fbd.SelectedPath != "")
                {
                    foreach (ItemInfo item in SrcFiles)
                    {
                        if (item.Type == FileType.File)
                            FileSystem.MoveFile(((LFileInfo)item.Info).FullName, fbd.SelectedPath + "\\" + ((LFileInfo)item.Info).Name, UIOption.AllDialogs);
                        else
                            FileSystem.MoveDirectory(((LDirectoryInfo)item.Info).FullName, fbd.SelectedPath + "\\" + ((LDirectoryInfo)item.Info).Name, UIOption.AllDialogs);
                    }
                }
            }
            catch (Exception ex)
            {
                MessageBox.Show(this, ex.Message, LControl_Language.strMsgCap1);
            }
        }

        protected override void CopyTo(ItemInfo[] SrcFiles)
        {
            try
            {
                FolderBrowserDialog fbd = new FolderBrowserDialog();
                fbd.Description = LControl_Language.strLF_CopyTip;
                fbd.ShowDialog();
                if (fbd.SelectedPath != "")
                {
                    foreach (ItemInfo item in SrcFiles)
                    {
                        if (item.Type == FileType.File)
                            FileSystem.CopyFile(((LFileInfo)item.Info).FullName, fbd.SelectedPath + "\\" + ((LFileInfo)item.Info).Name, UIOption.AllDialogs);
                        else
                            FileSystem.CopyDirectory(((LDirectoryInfo)item.Info).FullName, fbd.SelectedPath + "\\" + ((LDirectoryInfo)item.Info).Name, UIOption.AllDialogs);
                    }
                }
            }
            catch (Exception ex)
            {
                MessageBox.Show(this, ex.Message, LControl_Language.strMsgCap1);
            }
        }

        protected override void Delete(ItemInfo[] Files)
        {
            try
            {
                foreach (ItemInfo item in Files)
                {
                    if (item.Type == FileType.File)
                        FileSystem.DeleteFile(((LFileInfo)item.Info).FullName, UIOption.AllDialogs, RecycleOption.SendToRecycleBin);
                    else
                        FileSystem.DeleteDirectory(((LDirectoryInfo)item.Info).FullName, UIOption.AllDialogs, RecycleOption.SendToRecycleBin);
                }

            }
            catch (Exception ex)
            {
                MessageBox.Show(this, ex.Message, LControl_Language.strMsgCap1);
            }
        }

        protected override void CustomOperation(object sender, ItemInfo[] Fils)
        {
        }

        protected override void OnFileDoubleClick(LFileInfo file)
        {
        }

        protected override void DrapFiles(string[] Files)
        {
            FileInfo fi = null;
            foreach (string item in Files)
            {
                fi = FileSystem.GetFileInfo(item);
                if ((fi.Attributes & FileAttributes.Directory) != 0)
                    FileSystem.CopyDirectory(item, this.CurrentPath + "\\" + fi.Name, UIOption.AllDialogs);
                else
                    FileSystem.CopyFile(item, this.CurrentPath + "\\" + fi.Name, UIOption.AllDialogs);
            }
        }

		protected override void RenameDirectory(LDirectoryInfo di,string name)
		{
			FileSystem.RenameDirectory(di.FullName, name);
		}

		protected override void RenameFile(LFileInfo fi, string name)
		{
			FileSystem.RenameFile(fi.FullName, name);
		}

        private void InitializeComponent()
        {
            this.SuspendLayout();
            // 
            // LocalFileBrowser
            // 
            this.AutoScaleDimensions = new System.Drawing.SizeF(6F, 12F);
            this.Name = "LocalFileBrowser";
            this.ResumeLayout(false);
            this.PerformLayout();

        }
    }
}
